/*************************************************************************
 *   2014 Microchip Technology Inc.
 *
 *  Project Name:    GestIC Message Decoding Demo V2.0
 *  FileName:        hw_profile.h
 *  Dependencies:
 *  Processor:       PIC18F14K50
 *  Compiler:        XC 8 v1.31
 *  IDE:             MPLAB X v2.15
 *  Hardware:        Hillstar I2C to USB bridge
 *  Company:         Microchip Technology Inc.
 * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *  Description:
 *  This file contains the header for the hardware profile
 *
 *
 *
 *
 *************************************************************************/
/**************************************************************************
 * MICROCHIP SOFTWARE NOTICE AND DISCLAIMER: You may use this software, and
 * any derivatives created by any person or entity by or on your behalf,
 * exclusively with Microchip's products in accordance with applicable
 * software license terms and conditions, a copy of which is provided for
 * your referencein accompanying documentation. Microchip and its licensors
 * retain all ownership and intellectual property rights in the
 * accompanying software and in all derivatives hereto.
 *
 * This software and any accompanying information is for suggestion only.
 * It does not modify Microchip's standard warranty for its products. You
 * agree that you are solely responsible for testing the software and
 * determining its suitability. Microchip has no obligation to modify,
 * test, certify, or support the software.
 *
 * THIS SOFTWARE IS SUPPLIED BY MICROCHIP "AS IS". NO WARRANTIES, WHETHER
 * EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED
 * WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY, AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE, ITS INTERACTION WITH
 * MICROCHIP'S PRODUCTS, COMBINATION WITH ANY OTHER PRODUCTS, OR USE IN ANY
 * APPLICATION.
 *
 * IN NO EVENT, WILL MICROCHIP BE LIABLE, WHETHER IN CONTRACT, WARRANTY,
 * TORT (INCLUDING NEGLIGENCE OR BREACH OF STATUTORY DUTY), STRICT
 * LIABILITY, INDEMNITY, CONTRIBUTION, OR OTHERWISE, FOR ANY INDIRECT,
 * SPECIAL, PUNITIVE, EXEMPLARY, INCIDENTAL OR CONSEQUENTIAL LOSS, DAMAGE,
 * FOR COST OR EXPENSE OF ANY KIND WHATSOEVER RELATED TO THE SOFTWARE,
 * HOWSOEVER CAUSED, EVEN IF MICROCHIP HAS BEEN ADVISED OF THE POSSIBILITY
 * OR THE DAMAGES ARE FORESEEABLE. TO THE FULLEST EXTENT ALLOWABLE BY LAW,
 * MICROCHIP'S TOTAL LIABILITY ON ALL CLAIMS IN ANY WAY RELATED TO THIS
 * SOFTWARE WILL NOT EXCEED THE AMOUNT OF FEES, IF ANY, THAT YOU HAVE PAID
 * DIRECTLY TO MICROCHIP FOR THIS SOFTWARE.
 *
 * MICROCHIP PROVIDES THIS SOFTWARE CONDITIONALLY UPON YOUR ACCEPTANCE OF
 * THESE TERMS.
 *************************************************************************/



#ifndef HW_PROFILE_H
#define	HW_PROFILE_H

#include <xc.h>
#include <stdint.h>

void hwInit(void);
static void mgcInit(void);


#if defined (__18F14K50)

    #define _XTAL_FREQ          48000000

    //Indicator LEDs
    #define mLED_1              LATCbits.LATC1
    #define mLED_1_TRIS         TRISCbits.TRISC1
    #define mLED_2              LATCbits.LATC3
    #define mLED_2_TRIS         TRISCbits.TRISC3

    //GestIC (MGC3130)
    #define MGC_MCLR        LATCbits.LATC6
    #define MGC_MCLR_PORT   PORTCbits.RC6
    #define MGC_MCLR_TRIS   TRISCbits.TRISC6

    #define MGC_TS_LAT      LATCbits.LATC0
    #define MGC_TS_PORT     PORTCbits.RC0
    #define MGC_TS_TRIS     TRISCbits.TRISC0
    #define MGC_TS_IF       INTCONbits.INTF
    #define MGC_TS_IE       INTCONbits.INTE

    #define MGC_SCL         LATBbits.LATB6
    #define MGC_SCL_TRIS    TRISBbits.TRISB6

    #define MGC_SDA_LAT     LATBbits.LATB4
    #define MGC_SDA_PORT    PORTBbits.RB4
    #define MGC_SDA_TRIS    TRISBbits.TRISB4

    #define MGC_SSPCON1_REG         SSPCON1
    #define MGC_SSPCON1_BITS        SSPCON1bits
    #define MGC_SSPCON2_REG         SSPCON2
    #define MGC_SSPCON2_BITS        SSPCON2bits
    #define MGC_SSPCON3_REG         SSPCON3
    #define MGC_SSPCON3_BITS        SSPCON3bits
    #define MGC_SSPSTAT_REG         SSPSTAT
    #define MGC_SSPSTAT_BITS        SSPSTATbits
    #define MGC_SSPMSK_REG          SSPMSK
    #define MGC_SSPMSK_BITS         SSPMSKbits
    #define MGC_SSPADD_REG          SSPADD
    #define MGC_SSPADD_BITS         SSPADDbits
    #define MGC_SSPBUF_REG          SSPBUF
    #define MGC_SSP_IE              PIE1bits.SSPIE
    #define MGC_SSP_IF              PIR1bits.SSPIF
    #define MGC_SSP_BCL_IE          PIE2bits.BCLIE
    #define MGC_SSP_BCL_IF          PIR2bits.BCLIF

    #define GESTIC_IN_RESET()       (MGC_MCLR_PORT == 0)

    #define mgc_checkSSPint()       (MGC_SSP_IE && MGC_SSP_IF)
    #define mgc_clrSSPint()         (MGC_SSP_IF = 0)

    #define mgc_checkTSint()        (MGC_TS_IE && MGC_TS_IF)
    #define mgc_clrTSint()          (MGC_TS_IF = 0)

    #define mgc_checkBCLint()       (MGC_SSP_BCL_IE && MGC_SSP_BCL_IF)
    #define mgc_clrBCLint()         (MGC_SSP_BCL_IF = 0)

    #define i2cTmr_checkInterrupt() (INTCONbits.TMR0IE && INTCONbits.TMR0IF) // (PIE1bits.TMR1IE && PIR1bits.TMR1IF)
    #define i2cTmr_clrInt()         INTCONbits.TMR0IF = 0;
    #define i2cTmr_Int_enable()          INTCONbits.T0IE = 1;	
    #define i2cTmr_stop()           (T0CONbits.TMR0ON = 0)
    #define i2cTmr_start()          (T0CONbits.TMR0ON = 1)
    #define i2cTmr_reset()          do {T0CONbits.TMR0ON = 0; \
                                    TMR0H = 0xFF; TMR0L = 0xEA;} while(0)       //stop timer, reset counter
#else
//other processors
#endif

#endif	/* HW_PROFILE_H */

