/*************************************************************************
 *   2014 Microchip Technology Inc.
 *
 *  Project Name:    GestIC Message Decoding Demo V2.0
 *  FileName:        main.c
 *  Dependencies:
 *  Processor:       PIC18F14K50
 *  Compiler:        XC 8 v1.31
 *  IDE:             MPLAB X v2.15
 *  Hardware:        Hillstar I2C to USB bridge
 *  Company:         Microchip Technology Inc.
 * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *  Description:
 *  main
 *
 *
 *
 *************************************************************************/
/**************************************************************************
 * MICROCHIP SOFTWARE NOTICE AND DISCLAIMER: You may use this software, and
 * any derivatives created by any person or entity by or on your behalf,
 * exclusively with Microchip's products in accordance with applicable
 * software license terms and conditions, a copy of which is provided for
 * your referencein accompanying documentation. Microchip and its licensors
 * retain all ownership and intellectual property rights in the
 * accompanying software and in all derivatives hereto.
 *
 * This software and any accompanying information is for suggestion only.
 * It does not modify Microchip's standard warranty for its products. You
 * agree that you are solely responsible for testing the software and
 * determining its suitability. Microchip has no obligation to modify,
 * test, certify, or support the software.
 *
 * THIS SOFTWARE IS SUPPLIED BY MICROCHIP "AS IS". NO WARRANTIES, WHETHER
 * EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED
 * WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY, AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE, ITS INTERACTION WITH
 * MICROCHIP'S PRODUCTS, COMBINATION WITH ANY OTHER PRODUCTS, OR USE IN ANY
 * APPLICATION.
 *
 * IN NO EVENT, WILL MICROCHIP BE LIABLE, WHETHER IN CONTRACT, WARRANTY,
 * TORT (INCLUDING NEGLIGENCE OR BREACH OF STATUTORY DUTY), STRICT
 * LIABILITY, INDEMNITY, CONTRIBUTION, OR OTHERWISE, FOR ANY INDIRECT,
 * SPECIAL, PUNITIVE, EXEMPLARY, INCIDENTAL OR CONSEQUENTIAL LOSS, DAMAGE,
 * FOR COST OR EXPENSE OF ANY KIND WHATSOEVER RELATED TO THE SOFTWARE,
 * HOWSOEVER CAUSED, EVEN IF MICROCHIP HAS BEEN ADVISED OF THE POSSIBILITY
 * OR THE DAMAGES ARE FORESEEABLE. TO THE FULLEST EXTENT ALLOWABLE BY LAW,
 * MICROCHIP'S TOTAL LIABILITY ON ALL CLAIMS IN ANY WAY RELATED TO THIS
 * SOFTWARE WILL NOT EXCEED THE AMOUNT OF FEES, IF ANY, THAT YOU HAVE PAID
 * DIRECTLY TO MICROCHIP FOR THIS SOFTWARE.
 *
 * MICROCHIP PROVIDES THIS SOFTWARE CONDITIONALLY UPON YOUR ACCEPTANCE OF
 * THESE TERMS.
 *************************************************************************/


#include <xc.h>
#include <stdint.h>
#include "main.h"
#include "hw_profile.h"
#include "i2c.h"
#include "msghandler.h"

volatile uint8_t mgcSSPintFlag = 0,      //interrupt flags
                i2cTimerIntFlag = 0,
                mgcBCLintFlag = 0;

uint8_t i2cMsgFlag = 0,                 //new i2c message from MGC
        countDownReset = 0,             //wait timers for i2c...
        countDownI2C = 0,
        waitTSline = 0;

void main(void) {
    hwInit();
    //Enable peripheral and global interrupts
    INTCONbits.PEIE = 1;
    INTCONbits.GIE = 1;

    while(1) {
        //ISR has set flag for I2C bus collision
        if(mgcBCLintFlag) {
            mgcBCLintFlag--;
            i2c_BCLhandler();
        }

        //TS line asserted by MGC3130
        if(!waitTSline && i2c_gestICSignalsI2C()) {
            i2c_TShandler();
        }

        //Want to start a write to MGC3130
        if(!waitTSline && i2cGestIC_len != 0) {
            i2c_startWrite();
        }

        //ISR has set SSP flag to service MGC3130
        if(!waitTSline && mgcSSPintFlag) {
            i2c_runstatemachine();
        }

        //New i2c message from MGC3130 to process
        if(i2cMsgFlag) {
            uint8_t cmd = mgcProcMsg();     //process the message
            i2cMsgFlag = 0;
            if(cmd != GI_NOGESTURE) {
                switch(cmd) {
//**********************************************
//User code below for acting on GestIC command
//**********************************************
                    case GI_TAP_WEST:
                    case GI_FLICK_WE:
                        mLED_1 = 0;
                        mLED_2 = 1;
                        break;

                    case GI_TAP_EAST:
                    case GI_FLICK_EW:
                        mLED_1 = 1;
                        mLED_2 = 0;
                        break;

                    case GI_TAP_SOUTH:
                    case GI_TAP_CENTER:
                    case GI_FLICK_SN:
                        mLED_1 = 1;
                        mLED_2 = 1;
                        break;

                    case GI_TAP_NORTH:
                    case GI_FLICK_NS:
                        mLED_1 = 0;
                        mLED_2 = 0;
                        break;

                    case GI_AIRWHEEL_CCW:
                        mLED_2 ^= 1;
                        break;

                    case GI_AIRWHEEL_CW:
                        mLED_1 ^= 1;
                        break;

                    default: break;
                }
            }
        }

        //ISR has set flag to service I2C timer
        if(i2cTimerIntFlag) {
            i2cTimerIntFlag = 0;
            if(waitTSline) {waitTSline--;}
            if(countDownI2C) {countDownI2C--;}
            if(countDownReset) {countDownReset--;}
        }
    }
}
