/*************************************************************************
 *   2014 Microchip Technology Inc.
 *
 *  Project Name:    GestIC Message Decoding Demo V2.0
 *  FileName:        msghandler.h
 *  Dependencies:
 *  Processor:       PIC18F14K50
 *  Compiler:        XC 8 v1.31
 *  IDE:             MPLAB X v2.15
 *  Hardware:        Hillstar I2C to USB bridge
 *  Company:         Microchip Technology Inc.
 * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *  Description:
 *  This file contains the header for the massage handler
 *
 *
 *
 *
 *************************************************************************/
/**************************************************************************
 * MICROCHIP SOFTWARE NOTICE AND DISCLAIMER: You may use this software, and
 * any derivatives created by any person or entity by or on your behalf,
 * exclusively with Microchip's products in accordance with applicable
 * software license terms and conditions, a copy of which is provided for
 * your referencein accompanying documentation. Microchip and its licensors
 * retain all ownership and intellectual property rights in the
 * accompanying software and in all derivatives hereto.
 *
 * This software and any accompanying information is for suggestion only.
 * It does not modify Microchip's standard warranty for its products. You
 * agree that you are solely responsible for testing the software and
 * determining its suitability. Microchip has no obligation to modify,
 * test, certify, or support the software.
 *
 * THIS SOFTWARE IS SUPPLIED BY MICROCHIP "AS IS". NO WARRANTIES, WHETHER
 * EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED
 * WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY, AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE, ITS INTERACTION WITH
 * MICROCHIP'S PRODUCTS, COMBINATION WITH ANY OTHER PRODUCTS, OR USE IN ANY
 * APPLICATION.
 *
 * IN NO EVENT, WILL MICROCHIP BE LIABLE, WHETHER IN CONTRACT, WARRANTY,
 * TORT (INCLUDING NEGLIGENCE OR BREACH OF STATUTORY DUTY), STRICT
 * LIABILITY, INDEMNITY, CONTRIBUTION, OR OTHERWISE, FOR ANY INDIRECT,
 * SPECIAL, PUNITIVE, EXEMPLARY, INCIDENTAL OR CONSEQUENTIAL LOSS, DAMAGE,
 * FOR COST OR EXPENSE OF ANY KIND WHATSOEVER RELATED TO THE SOFTWARE,
 * HOWSOEVER CAUSED, EVEN IF MICROCHIP HAS BEEN ADVISED OF THE POSSIBILITY
 * OR THE DAMAGES ARE FORESEEABLE. TO THE FULLEST EXTENT ALLOWABLE BY LAW,
 * MICROCHIP'S TOTAL LIABILITY ON ALL CLAIMS IN ANY WAY RELATED TO THIS
 * SOFTWARE WILL NOT EXCEED THE AMOUNT OF FEES, IF ANY, THAT YOU HAVE PAID
 * DIRECTLY TO MICROCHIP FOR THIS SOFTWARE.
 *
 * MICROCHIP PROVIDES THIS SOFTWARE CONDITIONALLY UPON YOUR ACCEPTANCE OF
 * THESE TERMS.
 *************************************************************************/

#ifndef MSGHANDLER_H
#define	MSGHANDLER_H

#include <stdint.h>

/** GENERAL DEFINES *******************************************************/
#define MSGID_SENSORDATAOUT 0x91

//StreamingOutput Mask (DataOutputConfig), bitmask, 2Bytes
#define STREAMOUT_DSPINFO      0x0001               //b0 : DSPInfo field
#define STREAMOUT_GESTUREINFO  0x0002               //b1 : GestureInfo field
#define STREAMOUT_TOUCHINFO    0x0004               //b2 : TouchInfo field
#define STREAMOUT_AIRWHEELINFO 0x0008               //b3 : AirWheelInfo field
#define STREAMOUT_XYZPOSITION  0x0010               //b4 : XYZPosition field

//SytemInfo Mask, bitmask, 1Byte
#define SI_POSVALID         0x01                    //b0 : PositionValid
#define SI_AIRWHEELVALID    0x02                    //b1 : AirWheelValid

//Tap Bitmask
#define BITSHIFT_TAP_SOUTH       5
#define BITSHIFT_TAP_WEST        6
#define BITSHIFT_TAP_NORTH       7
#define BITSHIFT_TAP_EAST        8
#define BITSHIFT_TAP_CENTER      9

//Gesture Info (decimal number)
#define GI_NOGESTURE        0
#define GI_GARBAGEMOD       1
#define GI_FLICK_WE         2
#define GI_FLICK_EW         3
#define GI_FLICK_SN         4
#define GI_FLICK_NS         5

//Tap Info
#define GI_TAP_WEST         50
#define GI_TAP_EAST         51
#define GI_TAP_SOUTH        52
#define GI_TAP_NORTH        53
#define GI_TAP_CENTER       54

//Airwheel Info
#define GI_AIRWHEEL_CW      90
#define GI_AIRWHEEL_CCW     91

#define MD_BUF_LEN 128

extern uint8_t i2cMsgFlag;

inline void md_start(void);
inline void md_next(uint8_t c);
uint8_t mgcProcMsg(void);

#endif	/* MSGHANDLER_H */

